Index: chrome/installer/util/google_update_settings.h |
diff --git a/chrome/installer/util/google_update_settings.h b/chrome/installer/util/google_update_settings.h |
index b7bf6125613e9c0e492566dd3be7474fc9d01b25..a8e43c426d9ef33a0b3fcd337a72cd5f78678f25 100644 |
--- a/chrome/installer/util/google_update_settings.h |
+++ b/chrome/installer/util/google_update_settings.h |
@@ -86,12 +86,12 @@ class GoogleUpdateSettings { |
bool consented); |
#endif |
- // Returns the metrics id set in the registry (that can be used in crash |
- // reports). If none found, returns empty string. |
- static bool GetMetricsId(std::string* metrics_id); |
+ // Returns the metrics client id backed up in the registry. If none found, |
+ // returns empty string. |
+ static bool LoadMetricsClientId(std::string* metrics_id); |
- // Sets the metrics id to be used in crash reports. |
- static bool SetMetricsId(const std::string& metrics_id); |
+ // Stores a backup of the metrics client id in the registry. |
+ static bool StoreMetricsClientId(const std::string& metrics_id); |
// Sets the machine-wide EULA consented flag required on OEM installs. |
// Returns false if the setting could not be recorded. |